// Product Data
const products = [
    {
        id: 1,
        name: 'Canada Tobacco Original',
        category: 'CANADA TOBACCO',
        brand: 'CANADA TOBACCO',
        price: 50.00,
        image: 'images/product-original.jpg',
        rating: 5
    },
    {
        id: 2,
        name: 'Canada Tobacco Silver',
        category: 'CANADA TOBACCO',
        brand: 'CANADA TOBACCO',
        price: 50.00,
        image: 'images/product-silver.jpg',
        rating: 5
    },
    {
        id: 3,
        name: 'Canada Full Flavour',
        category: 'CANADA TOBACCO',
        brand: 'CANADA TOBACCO',
        price: 50.00,
        image: 'images/product-full-flavour.jpg',
        rating: 4
    },
    {
        id: 4,
        name: 'Canada Lights Cigarettes',
        category: 'CANADA TOBACCO',
        brand: 'CANADA TOBACCO',
        price: 50.00,
        image: 'images/product-lights.jpg',
        rating: 5
    },
    {
        id: 5,
        name: 'Canada Menthol',
        category: 'CANADA TOBACCO',
        brand: 'CANADA TOBACCO',
        price: 50.00,
        image: 'images/product-menthol.jpg',
        rating: 5
    },
    {
        id: 6,
        name: 'Canada Premium Original Cigarettes',
        category: 'CANADA TOBACCO',
        brand: 'CANADA TOBACCO',
        price: 50.00,
        image: 'images/product-premium.jpg',
        rating: 5
    },
    {
        id: 7,
        name: 'Canada Ultra Light Cigarettes',
        category: 'CANADA TOBACCO',
        brand: 'CANADA TOBACCO',
        price: 50.00,
        image: 'images/product-ultra-light.jpg',
        rating: 5
    }
];

// Save products to localStorage for admin panel
localStorage.setItem('products', JSON.stringify(products));
localStorage.setItem('adminProducts', JSON.stringify(products));

// DOM Elements
const productsGrid = document.querySelector('.products-grid');
const cartBtn = document.querySelector('.cart-btn');
const cartModal = document.getElementById('cartModal');
const closeCartBtn = document.querySelector('.close-cart');
const cartCount = document.querySelector('.cart-count');
const cartItems = document.querySelector('.cart-items');
const totalAmount = document.querySelector('.total-amount');
const checkoutBtn = document.querySelector('.btn-checkout');

// Cart
let cart = [];

// Function to render product cards
function renderProducts() {
    const productsGrid = document.querySelector('.products-grid');
    if (!productsGrid) return;

    // Clear existing content
    productsGrid.innerHTML = '';

    // Loop through all products
    products.forEach((product, index) => {
        // Create star rating HTML
        let ratingHtml = '';
        for (let i = 1; i <= 5; i++) {
            if (i <= product.rating) {
                ratingHtml += '<i class="fas fa-star"></i>';
            } else {
                ratingHtml += '<i class="far fa-star"></i>';
            }
        }

        // Create product card HTML
        const productCard = document.createElement('div');
        productCard.className = 'product-card';
        productCard.innerHTML = `
            <div class="product-image">
                <img src="${product.image}" alt="${product.name}">
            </div>
            <div class="product-info">
                <div class="product-brand">${product.category}</div>
                <h3 class="product-title">${product.name}</h3>
                <div class="product-rating">
                    ${ratingHtml}
                </div>
                <div class="product-price">$${product.price.toFixed(2)}</div>
                <div class="product-quantity">
                    <button class="quantity-btn dec" data-index="${index}">-</button>
                    <input type="text" class="quantity-input" value="1" readonly data-index="${index}">
                    <button class="quantity-btn inc" data-index="${index}">+</button>
                </div>
                <button class="btn btn-cart" data-index="${index}">Shopping Cart</button>
            </div>
        `;

        // Add the card to the grid
        productsGrid.appendChild(productCard);

        // Add event listeners for quantity buttons
        const decreaseBtn = productCard.querySelector('.dec');
        const increaseBtn = productCard.querySelector('.inc');
        const quantityInput = productCard.querySelector('.quantity-input');
        const addToCartBtn = productCard.querySelector('.btn-cart');

        decreaseBtn.addEventListener('click', handleQuantityChange);
        increaseBtn.addEventListener('click', handleQuantityChange);
        addToCartBtn.addEventListener('click', () => addToCart(index));
    });
}

// Event Listeners
document.addEventListener('DOMContentLoaded', () => {
    renderProducts(); // Add this line to render products on page load
    loadCart();
    setupEventListeners();
});

// Setup Event Listeners
function setupEventListeners() {
    // Cart modal
    cartBtn.addEventListener('click', openCart);
    closeCartBtn.addEventListener('click', closeCart);

    // Checkout button
    checkoutBtn.addEventListener('click', proceedToCheckout);
}

// Cart Functions
function loadCart() {
    const savedCart = localStorage.getItem('cart');
    if (savedCart) {
        cart = JSON.parse(savedCart);
        updateCartDisplay();
    }
}

function saveCart() {
    localStorage.setItem('cart', JSON.stringify(cart));
}

function addToCart(index) {
    const product = products[index];
    const quantityInput = document.querySelector(`.quantity-input[data-index="${index}"]`);
    const quantity = parseInt(quantityInput.value);

    // Check if product is already in cart
    const existingItemIndex = cart.findIndex(item => item.id === product.id);

    if (existingItemIndex !== -1) {
        // Update quantity if product already in cart
        cart[existingItemIndex].quantity += quantity;
    } else {
        // Add new item to cart
        cart.push({
            ...product,
            quantity: quantity
        });
    }

    saveCart();
    updateCartDisplay();
    showNotification(`${product.name} added to cart!`);
}

function removeFromCart(id) {
    cart = cart.filter(item => item.id !== id);
    saveCart();
    updateCartDisplay();
    showNotification('Item removed from cart!', 'error');
}

function updateCartDisplay() {
    // Update cart count
    const totalItems = cart.reduce((total, item) => total + item.quantity, 0);
    cartCount.textContent = totalItems;

    // Update cart items
    cartItems.innerHTML = '';

    if (cart.length === 0) {
        cartItems.innerHTML = '<p>Your cart is empty</p>';
    } else {
        cart.forEach(item => {
            const cartItemEl = document.createElement('div');
            cartItemEl.className = 'cart-item';
            cartItemEl.innerHTML = `
                <img src="${item.image}" alt="${item.name}" class="cart-item-img">
                <div class="cart-item-info">
                    <h3 class="cart-item-title">${item.name}</h3>
                    <p class="cart-item-price">$${item.price.toFixed(2)}</p>
                    <div class="cart-item-quantity">
                        <button class="quantity-btn cart-dec" data-id="${item.id}">-</button>
                        <span>${item.quantity}</span>
                        <button class="quantity-btn cart-inc" data-id="${item.id}">+</button>
                    </div>
                </div>
                <button class="cart-remove-btn" data-id="${item.id}">Remove</button>
            `;
            cartItems.appendChild(cartItemEl);
        });

        // Add event listeners to cart item buttons
        document.querySelectorAll('.cart-dec').forEach(btn => {
            btn.addEventListener('click', () => updateCartItemQuantity(parseInt(btn.dataset.id), -1));
        });
        document.querySelectorAll('.cart-inc').forEach(btn => {
            btn.addEventListener('click', () => updateCartItemQuantity(parseInt(btn.dataset.id), 1));
        });
        document.querySelectorAll('.cart-remove-btn').forEach(btn => {
            btn.addEventListener('click', () => removeFromCart(parseInt(btn.dataset.id)));
        });
    }

    // Update total amount
    const total = cart.reduce((total, item) => total + (item.price * item.quantity), 0);
    totalAmount.textContent = `$${total.toFixed(2)}`;
}

function updateCartItemQuantity(id, change) {
    const itemIndex = cart.findIndex(item => item.id === id);

    if (itemIndex !== -1) {
        cart[itemIndex].quantity += change;

        // Remove item if quantity is 0 or less
        if (cart[itemIndex].quantity <= 0) {
            removeFromCart(id);
        } else {
            saveCart();
            updateCartDisplay();
        }
    }
}

function handleQuantityChange(e) {
    const btn = e.target;
    const index = btn.getAttribute('data-index');
    if (!index) return;

    const input = document.querySelector(`.quantity-input[data-index="${index}"]`);
    if (!input) return;

    let value = parseInt(input.value);

    if (btn.classList.contains('dec')) {
        value = Math.max(1, value - 1);
    } else if (btn.classList.contains('inc')) {
        value += 1;
    }

    input.value = value;
}

function openCart() {
    cartModal.classList.add('active');
}

function closeCart() {
    cartModal.classList.remove('active');
}

function proceedToCheckout() {
    if (cart.length === 0) {
        showNotification('Your cart is empty!', 'error');
        return;
    }

    // Redirect to checkout page
    window.location.href = 'checkout.html';
}

// Notification
function showNotification(message, type = 'success') {
    // Remove existing notification if any
    const existingNotification = document.querySelector('.notification');
    if (existingNotification) {
        existingNotification.remove();
    }

    // Create notification element
    const notification = document.createElement('div');
    notification.className = `notification ${type}`;
    notification.textContent = message;

    // Add notification to DOM
    document.body.appendChild(notification);

    // Show notification
    setTimeout(() => {
        notification.classList.add('show');
    }, 10);

    // Auto-hide notification after 3 seconds
    setTimeout(() => {
        notification.classList.remove('show');
        setTimeout(() => {
            notification.remove();
        }, 300);
    }, 3000);
}
